class ReactComponentCalledDirectly(Exception):
    pass


class ReactComponentMissingSource(Exception):
    pass


class SourceFileNotFound(Exception):
    pass


class PropSerializationError(Exception):
    pass


class RenderingError(Exception):
    pass


class ComponentBundlingError(Exception):
    pass